@@ -1,7 +1,7 @@
 "This module contains the classes for the validation results."
 
 from abc import ABC
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
 import attrs
 import maus.models.edifact_components
@@ -168,3 +168,74 @@ class ValidationResultInContextSchema(Schema):
         so that the discriminator is the key and the validation_result the value.
         """
         return ValidationResultInContext(**data)
+
+
+@attrs.define(auto_attribs=True, kw_only=True)
+class ListOfValidationResultInContext:
+    """
+    Class to set validation result in context, for example with its discriminator.
+    This class is basically a wrapper around the list to have one place where the methods operating on the list do live.
+    """
+
+    validation_results: List[ValidationResultInContext] = attrs.field(
+        validator=attrs.validators.deep_iterable(
+            member_validator=attrs.validators.instance_of(ValidationResultInContext),
+            iterable_validator=attrs.validators.instance_of(list),
+        )
+    )
+
+    def replace_edi_domain_paths_with_application_domain_paths(
+        self, edi_domain_to_application_domain_mappings: Dict[str, str]
+    ) -> None:
+        """
+        replaces the edi domain discriminators in the list of validation results with the respective
+        values from the application domain if present
+
+        :param edi_domain_to_application_domain_mappings: dictionary with edi domain paths as keys
+            and application domain paths as values, for example ediseed to bo4e mapping:
+            "$[Dokument][0]['Transaktionsgrund']": "$['transaktionsdaten']['transaktionsgrund']"
+        :return:
+        """
+        for validation_result in self.validation_results:
+            if validation_result.discriminator.startswith("$"):
+                edi_seed_path = validation_result.discriminator
+                if edi_seed_path in edi_domain_to_application_domain_mappings:
+                    bo4e_path = edi_domain_to_application_domain_mappings[edi_seed_path]
+                    validation_result.discriminator = bo4e_path
+
+    def filter_for_data_element_validation_results(self) -> None:
+        """
+        Filters the lost of validation results for only DataElementValidationResults
+        """
+        self.validation_results = list(
+            filter(lambda vr: isinstance(vr.validation_result, DataElementValidationResult), self.validation_results)
+        )
+
+    @staticmethod
+    def _is_boneycomb_path_result(validation_result_in_context: ValidationResultInContext) -> bool:
+        return (
+            "stammdaten" in validation_result_in_context.discriminator
+            or "transaktionsdaten" in validation_result_in_context.discriminator
+        )
+
+    def filter_for_boneycomb_path_results(self) -> None:
+        """
+        Filters the list of validation results for those that have a boneycomb path as discriminator
+        """
+        self.validation_results = list(filter(self._is_boneycomb_path_result, self.validation_results))
+
+
+class ListOfValidationResultInContextSchema(Schema):
+    """
+    A schema to deserialize ListOfValidationResultInContext
+    """
+
+    validation_results = fields.List(fields.Nested(ValidationResultInContextSchema))
+
+    # pylint:disable=unused-argument
+    @post_load
+    def deserialize(self, data, **kwargs) -> ListOfValidationResultInContext:
+        """
+        Deserializes a ValidationResultDiscriminator
+        """
+        return ListOfValidationResultInContext(**data)
